@@ -23,6 +23,7 @@ from kivy.metrics import sp,dp,mm
 from kivy.core.window import WindowBase, Window
 from kivy.properties import BooleanProperty
 from kivy.uix.widget import Widget
+from kivy.clock import mainthread
 from kivy.uix.modalview import ModalView
 from kivy.app import App
 from kivy.factory import Factory
@@ -110,10 +111,7 @@ class Blocks(EventDispatcher):
 		self.register_event_type('on_failed')
 		self.env = GlobalEnv()
 		config = getConfig()
-		if config.script_root:
-			self.script = Script(config.script_root)
-		else:
-			self.script = Script(config.workdir)
+		self.script = Script()
 
 	def set(self, k:str, v):
 		self.env[k] = v
